@@ -18,7 +18,7 @@ ssl = get_satchmo_setting('SSL', default_value=False)
 urlpatterns = patterns('',
     (r'^$', 'payment.modules.sermepa.views.pay_ship_info', {'SSL': ssl}, 'SERMEPA_satchmo_checkout-step2'),
     (r'^confirm/$', 'payment.modules.sermepa.views.confirm_info', {'SSL': ssl}, 'SERMEPA_satchmo_checkout-step3'),
-    (r'^success/$', 'payment.views.checkout.success', {'SSL': ssl}, 'SERMEPA_satchmo_checkout-success'),
+    (r'^success/$', 'payment.modules.sermepa.views.success', {'SSL': ssl}, 'SERMEPA_satchmo_checkout-success'),
     (r'^failure/$', 'payment.views.checkout.failure', {'SSL': ssl}, 'SERMEPA_satchmo_checkout-failure'),
     (
         r'^notify/$',
