@@ -2,10 +2,12 @@ from decimal import Decimal
 from django import forms
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
+from django.utils.encoding import smart_str
 from product.models import Option, Product, ProductPriceLookup, OptionGroup, Price ,make_option_unique_id
 from product.prices import get_product_quantity_price, get_product_quantity_adjustments
 from satchmo_utils import cross_list
 from satchmo_utils.unique_id import slugify
+import config # livesettings options
 import datetime
 import logging
 
@@ -280,12 +282,15 @@ class ProductVariation(models.Model):
 
     objects = ProductVariationManager()
 
+    def _get_self_qty_price_list(self, qty=1):
+        return Price.objects.filter(product__id=self.product.id).exclude(expires__isnull=False, expires__lt=datetime.date.today()).filter(quantity__lte=qty)
+    
     def _get_fullPrice(self):
         """ Get price based on parent ConfigurableProduct """
         # allow explicit setting of prices.
         #qty_discounts = self.price_set.exclude(expires__isnull=False, expires__lt=datetime.date.today()).filter(quantity__lte=1)
         try:
-            qty_discounts = Price.objects.filter(product__id=self.product.id).exclude(expires__isnull=False, expires__lt=datetime.date.today())
+            qty_discounts = self._get_self_qty_price_list()
             if qty_discounts.count() > 0:
                 # Get the price with the quantity closest to the one specified without going over
                 return qty_discounts.order_by('-quantity')[0].dynamic_price
@@ -322,7 +327,7 @@ class ProductVariation(models.Model):
 
     def _optionkey(self):
         #todo: verify ordering
-        optkeys = [str(x) for x in self.options.values_list('value', flat=True).order_by('option_group__id')]
+        optkeys = [smart_str(x) for x in self.options.values_list('value', flat=True).order_by('option_group__id')]
         return "::".join(optkeys)
     optionkey = property(fget=_optionkey)
 
@@ -360,10 +365,13 @@ class ProductVariation(models.Model):
         return(False)
 
     def get_qty_price(self, qty, include_discount=True):
+        # if no prices have been set specifically for this variation, we derive a price from the parent
+        # if a price *has* been set (for the appropriate quantity), the delta is ignored, and the price is used as-is
+        should_use_delta = len(self._get_self_qty_price_list(qty)) == 0
         if include_discount:
             price = get_product_quantity_price(
                 self.product, qty,
-                delta=self.price_delta(False),
+                delta=(0, self.price_delta(False))[should_use_delta],
                 parent=self.parent.product)
         else:
             adjustment = get_product_quantity_adjustments(self, qty, parent=self.parent.product)
@@ -376,7 +384,7 @@ class ProductVariation(models.Model):
 
     def get_qty_price_list(self):
         """Return a list of tuples (qty, price)"""
-        prices = Price.objects.filter(product__id=self.product.id).exclude(expires__isnull=False, expires__lt=datetime.date.today())
+        prices = self._get_self_qty_price_list()
         if prices.count() > 0:
             # prices directly set, return them
             pricelist = [(price.quantity, price.dynamic_price) for price in prices]
@@ -391,8 +399,10 @@ class ProductVariation(models.Model):
     def _is_shippable(self):
         product = self.product
         parent = self.parent.product
-        return ((product.shipclass == "DEFAULT" and parent.shipclass == "DEFAULT")
-                or product.shipclass == 'YES')
+        return (product.shipclass == 'YES' or
+                (product.shipclass == "DEFAULT"
+                 and parent.shipclass in ("DEFAULT", "YES"))
+                )
 
     is_shippable = property(fget=_is_shippable)
 
@@ -415,9 +425,18 @@ class ProductVariation(models.Model):
 
         pvs = ProductVariation.objects.filter(parent=self.parent)
         pvs = pvs.exclude(product=self.product)
+        
         for pv in pvs:
             if pv.unique_option_ids == self.unique_option_ids:
-                return # Don't allow duplicates
+                return
+        # TODO: The following code snippet was introduced as an optimization in commit 2229
+        # see ticket #1312 for details.
+        # Unfortunately it is not working, see ticket #1318
+        #for option in self.options.all():
+        #    pvs = pvs.filter(options__option_group__id=option.option_group_id, 
+        #        options__value=option.value)
+        #if pvs.count():
+        #    return # Don't allow duplicates
 
         if not self.product.name:
             # will force calculation of default name
@@ -462,3 +481,4 @@ class ProductVariation(models.Model):
 
     def __unicode__(self):
         return self.product.slug
+
