@@ -1,4 +1,5 @@
 from satchmo_ext.newsletter import update_subscription
+from satchmo_ext.newsletter.models import Subscription
 from satchmo_store.contact.forms import ContactInfoForm
 from signals_ahoy.signals import collect_urls, form_postsave
 import logging
@@ -7,7 +8,11 @@ log = logging.getLogger('newsletter.listeners')
 
 def contact_form_listener(sender, object=None, formdata=None, form=None, **kwargs):
     if 'newsletter' not in formdata:
-        subscribed = False
+        email = formdata.get('email', None)
+        if Subscription.email_is_subscribed(email):
+                subscribed = True
+        else:
+                subscribed = False
     else:
         subscribed = formdata['newsletter']
     
