@@ -1,4 +1,6 @@
 from django import template
+
+from livesettings import config_get_group
 from satchmo_utils.templatetags import get_filter_args
 
 register = template.Library()
@@ -30,12 +32,12 @@ def order_variable(order, args):
 
     """
     args, kwargs = get_filter_args(args)
-    if not len(args == 1):
-        raise template.TemplateSyntaxError("%r filter expected variable, got: %s" % (args[0], args))
+    if len(args) != 1:
+        raise template.TemplateSyntaxError("%r filter expected only a variable, got: %s" % (args[0], args))
 
     return order.get_variable(args[0])
 
-register.filter(order_variable)    
+register.filter(order_variable)
 
 # def giftcertificate(order):
 #     """Get the giftcertificate from the order, if any"""
@@ -43,7 +45,20 @@ register.filter(order_variable)
 #         return GiftCertificate.objects.from_order(order)
 #     except GiftCertificate.DoesNotExist:
 #         pass
-#             
+#
 #     return None
 #
 # register.filter(giftcertificate)
+
+@register.filter
+def order_payment_methods(order):
+    """
+    Returns a list of payment method labels for an order.
+
+    Usage::
+
+      {{ order|order_payment_methods|join:", " }}
+
+    """
+    return (config_get_group('PAYMENT_%s' % p.payment).LABEL.value
+             for p in order.payments.all())
