@@ -1,6 +1,5 @@
 from django import forms
-from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ugettext as _
 from django.utils.safestring import mark_safe
 from satchmo_utils.thumbnail.utils import make_admin_thumbnail
 
